==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/ReportDatasetConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.ReportDatasetConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The configuration of dataset in the report.
 * @property columns Array of column names to be included in the report. Any valid report column name is allowed. If not provided, then report includes all columns.
 */
public data class ReportDatasetConfigurationArgs(
    public val columns: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.ReportDatasetConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.ReportDatasetConfigurationArgs =
        com.pulumi.azurenative.costmanagement.inputs.ReportDatasetConfigurationArgs.builder()
            .columns(columns?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ReportDatasetConfigurationArgs].
 */
@PulumiTagMarker
public class ReportDatasetConfigurationArgsBuilder internal constructor() {
    private var columns: Output<List<String>>? = null

    /**
     * @param value Array of column names to be included in the report. Any valid report column name is allowed. If not provided, then report includes all columns.
     */
    @JvmName("byncxniotltsxlxn")
    public suspend fun columns(`value`: Output<List<String>>) {
        this.columns = value
    }

    @JvmName("ouqikwfgcafiuxqx")
    public suspend fun columns(vararg values: Output<String>) {
        this.columns = Output.all(values.asList())
    }

    /**
     * @param values Array of column names to be included in the report. Any valid report column name is allowed. If not provided, then report includes all columns.
     */
    @JvmName("yhwnftiaqdmsirgk")
    public suspend fun columns(values: List<Output<String>>) {
        this.columns = Output.all(values)
    }

    /**
     * @param value Array of column names to be included in the report. Any valid report column name is allowed. If not provided, then report includes all columns.
     */
    @JvmName("agoppgvnnrgjycnx")
    public suspend fun columns(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.columns = mapped
    }

    /**
     * @param values Array of column names to be included in the report. Any valid report column name is allowed. If not provided, then report includes all columns.
     */
    @JvmName("xmijygpaxdojtwmw")
    public suspend fun columns(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.columns = mapped
    }

    internal fun build(): ReportDatasetConfigurationArgs = ReportDatasetConfigurationArgs(
        columns = columns,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/ReportDatasetConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.ReportDatasetConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The configuration of dataset in the report.
 * @property columns Array of column names to be included in the report. Any valid report column name is allowed. If not provided, then report includes all columns.
 */
public data class ReportDatasetConfigurationArgs(
    public val columns: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.ReportDatasetConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.ReportDatasetConfigurationArgs =
        com.pulumi.azurenative.costmanagement.inputs.ReportDatasetConfigurationArgs.builder()
            .columns(columns?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ReportDatasetConfigurationArgs].
 */
@PulumiTagMarker
public class ReportDatasetConfigurationArgsBuilder internal constructor() {
    private var columns: Output<List<String>>? = null

    /**
     * @param value Array of column names to be included in the report. Any valid report column name is allowed. If not provided, then report includes all columns.
     */
    @JvmName("xfcedfbcojucmosw")
    public suspend fun columns(`value`: Output<List<String>>) {
        this.columns = value
    }

    @JvmName("snijgibacsfuqhcq")
    public suspend fun columns(vararg values: Output<String>) {
        this.columns = Output.all(values.asList())
    }

    /**
     * @param values Array of column names to be included in the report. Any valid report column name is allowed. If not provided, then report includes all columns.
     */
    @JvmName("rsfgqprtexjohjey")
    public suspend fun columns(values: List<Output<String>>) {
        this.columns = Output.all(values)
    }

    /**
     * @param value Array of column names to be included in the report. Any valid report column name is allowed. If not provided, then report includes all columns.
     */
    @JvmName("hhehvkoddifobcrk")
    public suspend fun columns(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.columns = mapped
    }

    /**
     * @param values Array of column names to be included in the report. Any valid report column name is allowed. If not provided, then report includes all columns.
     */
    @JvmName("qgpaahxemoogsfqg")
    public suspend fun columns(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.columns = mapped
    }

    internal fun build(): ReportDatasetConfigurationArgs = ReportDatasetConfigurationArgs(
        columns = columns,
    )
}
